#! /bin/sh

name=`which $0`
if [ -z `echo $name | grep -e '^\/'` ] ; then
  path=`pwd`/$name
else
  path=$name
fi

dir=`dirname "$path"`

pkg_name_npm=$1
pkg_name=`"$dir"/to_camel.sh "$pkg_name_npm"`
pkg_version=$2

cd "$dir" >/dev/null  2>&1
wrapper_name_raw=$(basename "$(pwd)")
wrapper_name=$("$dir"/to_camel.sh "$wrapper_name_raw")
cd - >/dev/null  2>&1


if [ $# -ge 3 ] ; then
  home_page="$3"/$wrapper_name
else
  echo "home_page is a must"
  exit -1
fi

if [ $# -ge 4 ] ; then
  author=$4
else
  author='no author'
fi

if [ $# -ge 5 ] ; then
  email=$5
else
  email='no email'
fi



podspec_file="${dir}/${wrapper_name}.podspec"
cat >"$podspec_file" <<POD_SPEC_CODE
Pod::Spec.new do |s|
  s.name             = '$wrapper_name'
  s.version          = '$pkg_version'
  s.summary          = "generated pod by copying codes from and adding podspec to npm package: $pkg_name_npm"
  s.description      = s.summary.to_s

  s.homepage         = '$home_page'
  s.license          = { :type => 'MIT', :file => 'LICENSE' }
  s.author           = { '$author' => '$email' }
  s.source           = { :git => '${home_page}.git', :tag => s.version.to_s }

  s.ios.deployment_target = '8.0'

  s.source_files = '${pkg_name_npm}/ios/**/*.{h,m}'
  s.xcconfig = { 'LIBRARY_SEARCH_PATHS' => "$\(SRCROOT\)/../node_modules/$wrapper_name_raw/$pkg_name_npm/ios/" }

  # s.public_header_files = 'Pod/Classes/**/*.h'
  # s.frameworks = 'UIKit', 'MapKit'
  # s.dependency 'AFNetworking', '~> 2.3'
end
POD_SPEC_CODE

fetch_output=`"${dir}"/fetch.sh $pkg_name_npm $pkg_version`
tgz_file=`echo $fetch_output | sed -nE 's/^tarball file: (.+)$/\1/p'`

# .gitignore
gitignore_path="${dir}/.gitignore"
tgz_file_ignore_line=''
if [ -f "$gitignore_path" ] ; then
  tgz_file_ignore_line=`grep "$tgz_file" "$gitignore_path" `
fi
if [ -z "$tgz_file_ignore_line" ] ; then
  echo "$tgz_file" >> "$gitignore_path"
fi


node << MODIFY_PACKAGE_JSON
var packageJsonPath = '${dir}/package.json';
var fs = require('fs');
var packageJson = fs.existsSync(packageJsonPath) ? require(packageJsonPath) : {};

var sourcePackageJson = require('$dir/$pkg_name_npm/package.json');
packageJson.name = '$wrapper_name_raw';
packageJson.version = '$pkg_version';
packageJson.main = '$pkg_name_npm/' + sourcePackageJson.main;
packageJson.files = ['$pkg_name_npm', '${wrapper_name}.podspec'];
fs.writeFileSync(packageJsonPath, JSON.stringify(packageJson, null, 2));
MODIFY_PACKAGE_JSON

echo "$pkg_name_npm@$pkg_version" >"${dir}/.wrapped-version"

